@@ -780,8 +780,9 @@ void mail_set_seq_saving(struct mail *mail, uint32_t seq);
 /* Returns true IF and only IF the mail has EITHER one of the
    attachment keywords set. If it has both, or none, it will return FALSE. */
 bool mail_has_attachment_keywords(struct mail *mail);
-/* Sets attachment keywords. */
-void mail_set_attachment_keywords(struct mail *mail);
+/* Sets attachment keywords. Returns -1 on error, 0 when no attachment(s) found,
+   and 1 if attachment was found. */
+int mail_set_attachment_keywords(struct mail *mail);
 
 void mailbox_set_deleted(struct mailbox *box);
 int mailbox_mark_index_deleted(struct mailbox *box, bool del);
